Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4)

Unified Diff: views/widget/widget_delegate.h

Issue 7790010: Revert 98679 - Restoring a session should restore window minimization state on Windows (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « views/widget/widget.cc ('k') | views/widget/widget_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: views/widget/widget_delegate.h
===================================================================
--- views/widget/widget_delegate.h (revision 98697)
+++ views/widget/widget_delegate.h (working copy)
@@ -10,7 +10,6 @@
#include "base/memory/scoped_ptr.h"
#include "ui/base/accessibility/accessibility_types.h"
-#include "ui/base/ui_base_types.h"
#include "views/view.h"
class SkBitmap;
@@ -98,16 +97,15 @@
// state restoration.
virtual std::wstring GetWindowName() const;
// Saves the window's bounds and "show" state. By default this uses the
// process' local state keyed by window name (See GetWindowName above). This
// behavior can be overridden to provide additional functionality.
- virtual void SaveWindowPlacement(const gfx::Rect& bounds,
- ui::WindowShowState show_state);
+ virtual void SaveWindowPlacement(const gfx::Rect& bounds, bool maximized);
- // Retrieves the window's bounds and "show" states.
+ // Retrieves the window's bounds and maximized states.
// This behavior can be overridden to provide additional functionality.
- virtual bool GetSavedWindowPlacement(gfx::Rect* bounds,
- ui::WindowShowState* show_state) const;
+ virtual bool GetSavedWindowBounds(gfx::Rect* bounds) const;
+ virtual bool GetSavedMaximizedState(bool* maximized) const;
// Returns true if the window's size should be restored. If this is false,
// only the window's origin is restored and the window is given its
Property changes on: views/widget/widget_delegate.h
@@ -98,16 +97,15 @@
// state restoration.
virtual std::wstring GetWindowName() const;
- // Saves the window's bounds and "show" state. By default this uses the
+ // Saves the window's bounds and maximized states. By default this uses the
// process' local state keyed by window name (See GetWindowName above). This
// behavior can be overridden to provide additional functionality.
___________________________________________________________________
Added: svn:mergeinfo
« no previous file with comments | « views/widget/widget.cc ('k') | views/widget/widget_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698